@@ -136,6 +136,26 @@ class TestActions(unittest.TestCase):
         context.kill(servicetostart)
         self.assertEqual(context.get_service(servicetostart).status(), [])
 
+    def test_successful_play_from_jar_without_waiting(self):
+        config_dir_override = os.path.join(os.path.dirname(__file__), "conf")
+        sm_application = smcontext.SmApplication(config_dir_override)
+        context = smcontext.SmContext(sm_application, None, False, False)
+        service_resolver = ServiceResolver(sm_application)
+
+        context.kill_everything()
+        time.sleep(5)
+
+        response1 = actions.start_one(context, "FAKE_NEXUS", True, False, None, port=None)
+        self.assertTrue(response1)
+        self.assertIsNotNone(context.get_service("FAKE_NEXUS").status())
+        time.sleep(5)
+
+        try:
+            servicetostart = ["PLAY_NEXUS_END_TO_END_TEST"]
+            actions.start_and_wait(service_resolver, context, servicetostart, fatjar=True, release=False, proxy=None, port=None, seconds_to_wait=None)
+        finally:
+            context.kill_everything()
+
     def test_failing_play_from_jar(self):
 
         config_dir_override = os.path.join(os.path.dirname(__file__), "conf")
@@ -197,6 +217,33 @@ class TestActions(unittest.TestCase):
         self.assertEqual(context.get_service("PYTHON_SIMPLE_SERVER_ASSETS_FRONTEND").status(), [])
         self.assertEqual(context.get_service("FAKE_NEXUS").status(), [])
 
+    def test_wait_on_assets_server(self):
+        config_dir_override = os.path.join(os.path.dirname(__file__), "conf")
+        sm_application = smcontext.SmApplication(config_dir_override)
+        context = smcontext.SmContext(sm_application, None, False, False)
+        service_resolver = ServiceResolver(sm_application)
+        context.kill_everything()
+
+        context.kill("FAKE_NEXUS")
+        self.assertEqual(context.get_service("FAKE_NEXUS").status(), [])
+        time.sleep(2)
+
+        # start fake nexus
+        self.assertEqual(context.get_service("FAKE_NEXUS").status(), [])
+        response1 = actions.start_one(context, "FAKE_NEXUS", True, False, None, port=None)
+        self.assertTrue(response1)
+        self.assertIsNotNone(context.get_service("FAKE_NEXUS").status())
+        time.sleep(5)
+
+        actions.start_and_wait(service_resolver, context, ["PYTHON_SIMPLE_SERVER_ASSETS_FRONTEND"], True, False, None, port=None, seconds_to_wait=5)
+        self.assertIsNotNone(context.get_service("PYTHON_SIMPLE_SERVER_ASSETS_FRONTEND").status())
+        context.kill("PYTHON_SIMPLE_SERVER_ASSETS_FRONTEND")
+        context.kill("FAKE_NEXUS")
+        time.sleep(15)
+
+        self.assertEqual(context.get_service("PYTHON_SIMPLE_SERVER_ASSETS_FRONTEND").status(), [])
+        self.assertEqual(context.get_service("FAKE_NEXUS").status(), [])
+
     def test_python_server_offline(self):
         config_dir_override = os.path.join(os.path.dirname(__file__), "conf")
         context = smcontext.SmContext(smcontext.SmApplication(config_dir_override), None, True, False)
@@ -239,7 +286,7 @@ class TestStartCommands(unittest.TestCase):
         context = smcontext.SmContext(smcontext.SmApplication(config_dir_override), None, False, False)
         starter = context.get_service_starter("DROPWIZARD_NEXUS_END_TO_END_TEST", "foo", proxy=None)
         expected = [
-            '/Library/Java/JavaVirtualMachines/jdk1.7.0_45.jdk/Contents/Home/bin/java',
+            'java',
             '-Dfile.encoding=UTF8',
             '-Xmx64M',
             '-XX:+CMSClassUnloadingEnabled',
@@ -254,6 +301,7 @@ class TestStartCommands(unittest.TestCase):
             'dev_config.yml']
         cmd = starter.get_start_command("BINARY")
         cmd[-1] = cmd[-1].split("/")[-1]
+        cmd[0] = cmd[0].split("/")[-1]
         cmd[len(cmd) -3] = cmd[len(cmd) -3].split("/")[-1]
         self.assertEqual(cmd, expected)
 
